==> openrpt-2.3.0-source.tar.bz2: openrpt-2.3.0-source/MetaSQL/metasql_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr">
<context>
    <name>LogOutput</name>
    <message>
        <location filename="logoutput.ui" line="32"/>
        <source>Log Output</source>
        <translation>Journal</translation>
    </message>
</context>
<context>
    <name>MQLEdit</name>
    <message>
        <location filename="mqledit.cpp" line="201"/>
        <source>Not Yet Implemented</source>
        <translation>Pas encore implémenté</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="201"/>
        <source>This function has not been implemented.</source>
        <translation>Cette fonction n&apos;a pas été implémentée.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="207"/>
        <source>About MetaSQL Editor</source>
        <translation>A propos de l&apos;éditeur MetaSQL</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="207"/>
        <source>About MetaSQL Editor version 2.3.0</source>
        <translation>A propos de l&apos;éditeur MetaSQL version 2.3.0</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="221"/>
        <source>Document Modified!</source>
        <translation>Document modifié!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="222"/>
        <source>Would you like to save your changes before continuing?</source>
        <translation>Voulez-vous enregistrer vos modifications avant de continuer ?</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="233"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="233"/>
        <source>Encountered an unknown response. No action will be taken.</source>
        <translation>J&apos;ai rencontré une réponse inconnue. Aucune action ne sera effectuée.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="248"/>
        <source>No file Specified</source>
        <translation>Pas de fichier spécifié</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="248"/>
        <source>No file was specified to save to.</source>
        <translation>Pas de fichier spécifié pour l&apos;enregistrement.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="258"/>
        <source>Error Saving file</source>
        <translation>Erreur à l&apos;enregistrement du fichier</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="258"/>
        <source>There was an error while trying to save the file.</source>
        <translation>Erreur à l&apos;enregistrement du fichier.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="353"/>
        <source>---- Parsing Query ----
</source>
        <translation>---- Evaluation de la requête ----
</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="357"/>
        <source>Query parsed.</source>
        <translation>Requête évaluée.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="386"/>
        <source>ERROR: Invalid query!</source>
        <translation>ERREUR: Requête invalide!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="344"/>
        <source>Not Connected</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="344"/>
        <source>You must be connected to a database in order to execute a query.</source>
        <translation>Vous devez être connecté à la base pour pouvoir exécuter une requête.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="358"/>
        <source>---- Executing Query ----</source>
        <translation>---- Exécution de la requête ----</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="381"/>
        <source>Failed to execute query.</source>
        <translation>Echec à l&apos;exécution de la requête.</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="31"/>
        <source>MetaSQL Editor</source>
        <translation>Editeur MetaSQL</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="87"/>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="103"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="112"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="125"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="348"/>
        <source>Database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="156"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="159"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="162"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="170"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="173"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="176"/>
        <source>Ctrl+O</source>
        <translation>Ctlr+O</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="184"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="187"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="190"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="195"/>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="198"/>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="209"/>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimer...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="212"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="215"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="220"/>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="223"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="234"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="237"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="240"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="245"/>
        <source>&amp;Redo</source>
        <translation>&amp;Répéter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="248"/>
        <source>Redo</source>
        <translation>Répéter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="251"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="259"/>
        <source>&amp;Cut</source>
        <translation>&amp;Couper</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="262"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="265"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="273"/>
        <source>C&amp;opy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="276"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="279"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="287"/>
        <source>&amp;Paste</source>
        <translation>&amp;Coller</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="290"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="293"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="301"/>
        <source>&amp;Find...</source>
        <translation>&amp;Rechercher...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="304"/>
        <source>Find</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="307"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="312"/>
        <source>&amp;Contents...</source>
        <translation>&amp;Contenu...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="315"/>
        <source>Contents</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="323"/>
        <source>&amp;Index...</source>
        <translation>&amp;Index...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="326"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="334"/>
        <source>&amp;About</source>
        <translation>&amp;A Propos</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="337"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="356"/>
        <source>Connect...</source>
        <translation>Connecter...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="364"/>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="372"/>
        <source>Unnamed</source>
        <translation>Sans nom</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="380"/>
        <source>Parameter List...</source>
        <translation>Liste de paramètres...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="388"/>
        <source>Log Output...</source>
        <translation>Journal...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="396"/>
        <source>Results...</source>
        <translation>Resultats...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="404"/>
        <source>Parse Query</source>
        <translation>Evaluer la requête</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="412"/>
        <source>Execute Query</source>
        <translation>Exécuter la requête</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="420"/>
        <source>Executed SQL...</source>
        <translation>SQL exécuté...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="mqledit.cpp" line="100"/>
        <source>MQLEdit for Windows</source>
        <translation>MQLEdit pour Windows</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="102"/>
        <source>MQLEdit for Linux</source>
        <translation>MQLEdit pour Linux</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="104"/>
        <source>MQLEdit for OS X</source>
        <translation>MQLEdit pour OS X</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="106"/>
        <source>MQLEdit</source>
        <translation>MQLEdit</translation>
    </message>
    <message>
        <location filename="data.cpp" line="26"/>
        <source>Copyright (c) 2002-2008, OpenMFG, LLC.</source>
        <translation>Copyright (c) 2002-2008, OpenMFG, LLC.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="92"/>
        <source>Can not load database driver</source>
        <translation>Impossible de se connecter au pilote de base de données</translation>
    </message>
    <message>
        <location filename="main.cpp" line="92"/>
        <source>Unable to load the database driver. Please contact your systems administrator.</source>
        <translation>Impossible de charger le pilot de la base. Veuillez contacter votre administrateur système.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="101"/>
        <source>Unable to connect to database</source>
        <translation>Impossible de se connecter à la base de données</translation>
    </message>
    <message>
        <location filename="main.cpp" line="101"/>
        <source>Unable to connect to the database with the given information.</source>
        <translation>Impossible de se connecter à la base de données avec ces informations.</translation>
    </message>
</context>
<context>
    <name>ResultsOutput</name>
    <message>
        <location filename="resultsoutput.ui" line="32"/>
        <source>Results Output</source>
        <translation>Résultats</translation>
    </message>
</context>
</TS>

==> openrpt-3.1.0-source.tar.bz2: openrpt-3.1.0-source/MetaSQL/metasql_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>LogOutput</name>
    <message>
        <location filename="logoutput.ui" line="30"/>
        <source>Log Output</source>
        <translation>Journal</translation>
    </message>
</context>
<context>
    <name>MQLEdit</name>
    <message>
        <location filename="mqledit.cpp" line="142"/>
        <location filename="mqledit.cpp" line="157"/>
        <location filename="mqledit.cpp" line="164"/>
        <location filename="mqledit.cpp" line="171"/>
        <source>Not Yet Implemented</source>
        <translation>Pas encore implémenté</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="143"/>
        <location filename="mqledit.cpp" line="158"/>
        <location filename="mqledit.cpp" line="165"/>
        <location filename="mqledit.cpp" line="172"/>
        <source>This function has not been implemented.</source>
        <translation>Cette fonction n&apos;a pas été implémentée.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="178"/>
        <source>About MetaSQL Editor</source>
        <translation>A propos de l&apos;éditeur MetaSQL</translation>
    </message>
    <message>
        <source>About MetaSQL Editor version 2.3.0</source>
        <translation type="obsolete">A propos de l&apos;éditeur MetaSQL version 2.3.0</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="179"/>
        <source>About MetaSQL Editor version 3.1.0</source>
        <translation>A propos de l&apos;éditeur MetaSQL version 3.1.0</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="193"/>
        <source>Document Modified!</source>
        <translation>Document modifié!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="194"/>
        <source>Would you like to save your changes before continuing?</source>
        <translation>Voulez-vous enregistrer vos modifications avant de continuer ?</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="205"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="206"/>
        <source>Encountered an unknown response. No action will be taken.</source>
        <translation>J&apos;ai rencontré une réponse inconnue. Aucune action ne sera effectuée.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="221"/>
        <source>No file Specified</source>
        <translation>Pas de fichier spécifié</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="222"/>
        <source>No file was specified to save to.</source>
        <translation>Pas de fichier spécifié pour l&apos;enregistrement.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="232"/>
        <source>Error Saving file</source>
        <translation>Erreur à l&apos;enregistrement du fichier</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="233"/>
        <source>There was an error while trying to save the file.</source>
        <translation>Erreur à l&apos;enregistrement du fichier.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="304"/>
        <location filename="mqledit.cpp" line="329"/>
        <source>---- Parsing Query ----
</source>
        <translation>---- Evaluation de la requête ----
</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="308"/>
        <location filename="mqledit.cpp" line="333"/>
        <source>Query parsed.</source>
        <translation>Requête évaluée.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="310"/>
        <location filename="mqledit.cpp" line="361"/>
        <source>ERROR: Invalid query!</source>
        <translation>ERREUR: Requête invalide!</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="319"/>
        <source>Not Connected</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="320"/>
        <source>You must be connected to a database in order to execute a query.</source>
        <translation>Vous devez être connecté à la base pour pouvoir exécuter une requête.</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="334"/>
        <source>---- Executing Query ----</source>
        <translation>---- Exécution de la requête ----</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="356"/>
        <source>Failed to execute query.</source>
        <translation>Echec à l&apos;exécution de la requête.</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="31"/>
        <source>MetaSQL Editor</source>
        <translation>Editeur MetaSQL</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="87"/>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="103"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="112"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="125"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="129"/>
        <location filename="mqledit.ui" line="345"/>
        <location filename="mqledit.ui" line="348"/>
        <source>Database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="156"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="159"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="162"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="170"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="173"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="176"/>
        <source>Ctrl+O</source>
        <translation>Ctlr+O</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="184"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="187"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="190"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="195"/>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="198"/>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="209"/>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimer...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="212"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="215"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="220"/>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="223"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="234"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="237"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="240"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="245"/>
        <source>&amp;Redo</source>
        <translation>&amp;Répéter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="248"/>
        <source>Redo</source>
        <translation>Répéter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="251"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="259"/>
        <source>&amp;Cut</source>
        <translation>&amp;Couper</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="262"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="265"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="273"/>
        <source>C&amp;opy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="276"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="279"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="287"/>
        <source>&amp;Paste</source>
        <translation>&amp;Coller</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="290"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="293"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="301"/>
        <source>&amp;Find...</source>
        <translation>&amp;Rechercher...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="304"/>
        <source>Find</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="307"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="312"/>
        <source>&amp;Contents...</source>
        <translation>&amp;Contenu...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="315"/>
        <source>Contents</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="323"/>
        <source>&amp;Index...</source>
        <translation>&amp;Index...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="326"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="334"/>
        <source>&amp;About</source>
        <translation>&amp;A Propos</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="337"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="353"/>
        <location filename="mqledit.ui" line="356"/>
        <source>Connect...</source>
        <translation>Connecter...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="361"/>
        <location filename="mqledit.ui" line="364"/>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="369"/>
        <location filename="mqledit.ui" line="372"/>
        <source>Unnamed</source>
        <translation>Sans nom</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="377"/>
        <location filename="mqledit.ui" line="380"/>
        <source>Parameter List...</source>
        <translation>Liste de paramètres...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="385"/>
        <location filename="mqledit.ui" line="388"/>
        <source>Log Output...</source>
        <translation>Journal...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="393"/>
        <location filename="mqledit.ui" line="396"/>
        <source>Results...</source>
        <translation>Resultats...</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="401"/>
        <location filename="mqledit.ui" line="404"/>
        <source>Parse Query</source>
        <translation>Evaluer la requête</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="409"/>
        <location filename="mqledit.ui" line="412"/>
        <source>Execute Query</source>
        <translation>Exécuter la requête</translation>
    </message>
    <message>
        <location filename="mqledit.ui" line="417"/>
        <location filename="mqledit.ui" line="420"/>
        <source>Executed SQL...</source>
        <translation>SQL exécuté...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="mqledit.cpp" line="387"/>
        <source>MQLEdit for Windows</source>
        <translation>MQLEdit pour Windows</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="389"/>
        <source>MQLEdit for Linux</source>
        <translation>MQLEdit pour Linux</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="391"/>
        <source>MQLEdit for OS X</source>
        <translation>MQLEdit pour OS X</translation>
    </message>
    <message>
        <location filename="mqledit.cpp" line="393"/>
        <source>MQLEdit</source>
        <translation>MQLEdit</translation>
    </message>
    <message>
        <location filename="data.cpp" line="25"/>
        <source>Copyright (c) 2002-2008, OpenMFG, LLC.</source>
        <translation>Copyright (c) 2002-2008, OpenMFG, LLC.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="92"/>
        <source>Can not load database driver</source>
        <translation>Impossible de se connecter au pilote de base de données</translation>
    </message>
    <message>
        <location filename="main.cpp" line="93"/>
        <source>Unable to load the database driver. Please contact your systems administrator.</source>
        <translation>Impossible de charger le pilot de la base. Veuillez contacter votre administrateur système.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="102"/>
        <source>Unable to connect to database</source>
        <translation>Impossible de se connecter à la base de données</translation>
    </message>
    <message>
        <location filename="main.cpp" line="103"/>
        <source>Unable to connect to the database with the given information.</source>
        <translation>Impossible de se connecter à la base de données avec ces informations.</translation>
    </message>
</context>
<context>
    <name>ResultsOutput</name>
    <message>
        <location filename="resultsoutput.ui" line="30"/>
        <source>Results Output</source>
        <translation>Résultats</translation>
    </message>
</context>
</TS>
